==> contained-react-1.1.7.tgz: package/index.esm.js <==
import { useMemo, useRef, useState, useEffect } from 'react';

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

  if (_i == null) return;
  var _arr = [];
  var _n = true;
  var _d = false;

  var _s, _e;

  try {
    for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) {
    arr2[i] = arr[i];
  }

  return arr2;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

/**
 * This converts an object or array into a primitive key.
 * This is useful for React hooks when you need a primitive key for the dependency array.
 *
 * We're using `JSON.stringify` to convert the object into a string.
 * This means that an reordering of the object or array will result in a different key.
 *
 * NOTE: Only do performance optimization when needed.
 *
 * @author @mthines
 *
 * @version 1.0.0
 *
 * @example
 * ```tsx
  const Component = () => {
    const key = useMemoKey(['a', 'b', 'c']); // <- This returns `["a","b","c"]`

    useEffect(() => {
      // Here is some heavy operation which should only execute when the `key` updates.
    }, [key])
  }
 * ```
 */

var useMemoKey = function useMemoKey(item) {
  return useMemo(function () {
    if (typeof item === 'string' || typeof item === 'number' || typeof item === 'boolean' || item === null || item === undefined) {
      return item;
    }

    return JSON.stringify(item);
  }, [item]);
};

var isServer = typeof window === 'undefined';

var getCalculatedSize = function getCalculatedSize(query) {
  var _query$split = query.split(':'),
      _query$split2 = _slicedToArray(_query$split, 2),
      calculator = _query$split2[0],
      size = _query$split2[1];

  return {
    type: calculator,
    size: parseInt(size, 10)
  };
};

var useContainerQuery = function useContainerQuery(query, options) {
  var _a;

  var ref = useRef(null);

  var _useState = useState(null),
      matches = _useState[0],
      setMatches = _useState[1];

  useEffect(function () {
    var _a;

    if (isServer || !ref.current) return;
    var observer = new ResizeObserver(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 1),
          entry = _ref2[0];

      var _getCalculatedSize = getCalculatedSize(query),
          size = _getCalculatedSize.size,
          type = _getCalculatedSize.type;

      if (type === 'min-width') {
        if (entry.contentRect.width >= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }

      if (type === 'max-width') {
        if (entry.contentRect.width <= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }

      if (type === 'min-height') {
        if (entry.contentRect.height >= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }

      if (type === 'max-height') {
        if (entry.contentRect.height <= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }
    });
    observer.observe(ref.current, {
      box: ((_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box) || 'border-box'
    });
    return function () {
      return observer.disconnect();
    };
  }, [(_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box, query]);
  return [ref, matches];
};
/**
 * Detecting multiple container queries within the same Element
 */

var useContainerQueries = function useContainerQueries(queries, options) {
  var _a;

  var ref = useRef(null);

  var _useState2 = useState({}),
      matches = _useState2[0],
      setMatches = _useState2[1];

  var queriesKey = useMemoKey(queries);
  useEffect(function () {
    var _a;

    if (isServer || !ref.current) return;
    var queriesEntries = Object.entries(queries);
    var observer = new ResizeObserver(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 1),
          entry = _ref4[0];

      var matchingBreakpoints = queriesEntries.reduce(function (acc, _ref5) {
        var _ref6 = _slicedToArray(_ref5, 2),
            name = _ref6[0],
            query = _ref6[1];

        var _getCalculatedSize2 = getCalculatedSize(query),
            size = _getCalculatedSize2.size,
            type = _getCalculatedSize2.type;

        if (type === 'min-width') {
          if (entry.contentRect.width >= size) {
            return Object.assign(Object.assign({}, acc), {
              width: name
            });
          }
        }

        if (type === 'max-width') {
          if (entry.contentRect.width <= size) {
            return Object.assign(Object.assign({}, acc), {
              width: name
            });
          }
        }

        if (type === 'min-height') {
          if (entry.contentRect.height >= size) {
            return Object.assign(Object.assign({}, acc), {
              height: name
            });
          }
        }

        if (type === 'max-height') {
          if (entry.contentRect.height <= size) {
            return Object.assign(Object.assign({}, acc), {
              height: name
            });
          }
        }

        return acc;
      }, {});

      if (Object.keys(matchingBreakpoints).length === 0) {
        setMatches({});
        return;
      }

      setMatches(matchingBreakpoints);
    });
    observer.observe(ref.current, {
      box: ((_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box) || 'border-box'
    });
    return function () {
      return observer.disconnect();
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [(_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box, queriesKey]);
  return [ref, matches];
};

export { useContainerQueries, useContainerQuery };

==> contained-react-1.3.0-3.tgz: package/index.esm.js <==
import { useMemo, useRef, useState, useEffect } from 'react';

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

  if (_i == null) return;
  var _arr = [];
  var _n = true;
  var _d = false;

  var _s, _e;

  try {
    for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) {
    arr2[i] = arr[i];
  }

  return arr2;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

/**
 * This converts an object or array into a primitive key.
 * This is useful for React hooks when you need a primitive key for the dependency array.
 *
 * We're using `JSON.stringify` to convert the object into a string.
 * This means that an reordering of the object or array will result in a different key.
 *
 * NOTE: Only do performance optimization when needed.
 *
 * @author @mthines
 *
 * @version 1.0.0
 *
 * @example
 * ```tsx
  const Component = () => {
    const key = useMemoKey(['a', 'b', 'c']); // <- This returns `["a","b","c"]`

    useEffect(() => {
      // Here is some heavy operation which should only execute when the `key` updates.
    }, [key])
  }
 * ```
 */

var useMemoKey = function useMemoKey(item) {
  return useMemo(function () {
    if (typeof item === 'string' || typeof item === 'number' || typeof item === 'boolean' || item === null || item === undefined) {
      return item;
    }

    return JSON.stringify(item);
  }, [item]);
};

var isServer = typeof window === 'undefined';

var getCalculatedSize = function getCalculatedSize(query) {
  var _query$split = query.split(':'),
      _query$split2 = _slicedToArray(_query$split, 2),
      calculator = _query$split2[0],
      size = _query$split2[1];

  return {
    type: calculator,
    size: parseInt(size, 10)
  };
};

var useContainerQuery = function useContainerQuery(query, options) {
  var _a;

  var ref = useRef(null);

  var _useState = useState(null),
      matches = _useState[0],
      setMatches = _useState[1];

  useEffect(function () {
    var _a;

    if (isServer || !ref.current) return;
    var observer = new ResizeObserver(function (_ref) {
      var _ref2 = _slicedToArray(_ref, 1),
          entry = _ref2[0];

      var _getCalculatedSize = getCalculatedSize(query),
          size = _getCalculatedSize.size,
          type = _getCalculatedSize.type;

      if (type === 'min-width') {
        if (entry.contentRect.width >= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }

      if (type === 'max-width') {
        if (entry.contentRect.width <= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }

      if (type === 'min-height') {
        if (entry.contentRect.height >= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }

      if (type === 'max-height') {
        if (entry.contentRect.height <= size) {
          setMatches(true);
        } else {
          setMatches(false);
        }

        return;
      }
    });
    observer.observe(ref.current, {
      box: ((_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box) || 'border-box'
    });
    return function () {
      return observer.disconnect();
    };
  }, [(_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box, query]);
  return [ref, matches];
};
/**
 * Detecting multiple container queries within the same Element
 */

var useContainerQueries = function useContainerQueries(queries, options) {
  var _a;

  var ref = useRef(null);

  var _useState2 = useState({
    width: undefined,
    height: undefined
  }),
      matches = _useState2[0],
      setMatches = _useState2[1];

  var queriesKey = useMemoKey(queries);
  useEffect(function () {
    var _a;

    if (isServer || !ref.current) return;
    var queriesEntries = Object.entries(queries);
    var observer = new ResizeObserver(function (_ref3) {
      var _ref4 = _slicedToArray(_ref3, 1),
          entry = _ref4[0];

      var matchingBreakpoints = queriesEntries.reduce(function (acc, _ref5) {
        var _ref6 = _slicedToArray(_ref5, 2),
            name = _ref6[0],
            query = _ref6[1];

        var _getCalculatedSize2 = getCalculatedSize(query),
            size = _getCalculatedSize2.size,
            type = _getCalculatedSize2.type;

        if (type === 'min-width') {
          if (entry.contentRect.width >= size) {
            return Object.assign(Object.assign({}, acc), {
              width: name
            });
          }
        }

        if (type === 'max-width') {
          if (entry.contentRect.width <= size) {
            return Object.assign(Object.assign({}, acc), {
              width: name
            });
          }
        }

        if (type === 'min-height') {
          if (entry.contentRect.height >= size) {
            return Object.assign(Object.assign({}, acc), {
              height: name
            });
          }
        }

        if (type === 'max-height') {
          if (entry.contentRect.height <= size) {
            return Object.assign(Object.assign({}, acc), {
              height: name
            });
          }
        }

        return acc;
      }, {});

      if (Object.keys(matchingBreakpoints).length === 0) {
        setMatches({});
        return;
      }

      setMatches(matchingBreakpoints);
    });
    observer.observe(ref.current, {
      box: ((_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box) || 'border-box'
    });
    return function () {
      return observer.disconnect();
    }; // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [(_a = options === null || options === void 0 ? void 0 : options.observeOptions) === null || _a === void 0 ? void 0 : _a.box, queriesKey]);
  return [ref, matches];
};

export { useContainerQueries, useContainerQuery };
